/*	@(#)view.h	11.6
 *	this file defines the constants and structures used by
 *	the view subroutines
 */

#define		MAXFLDSIZE	150	/* largest possible screen field size */


/*
 *	view data entry modes
 */

#define	V_NOMODE	0
#define	V_QUERY		1
#define	V_FIND		2
#define	V_UPDATE	3
#define	V_ADD		4

	/* special, temporary modes */

#define	V_SEARCH	5		/* SEARCHING */
#define	V_WORK		6		/* WORKING */


/*
 *	keys allowed from current mode
 */

#define	K_PREV		  01
#define	K_NEXT		  02
#define	K_UPDATE	  04
#define	K_ADD		 010
#define	K_STORE		 020
#define	K_SWITCH	 040
#define	K_EXIT		0100
#define	K_HELP		0200
#define	K_CANCEL	0400
#define K_QUERY		01000
#define K_FIND		02000
#define K_REFRESH	04000
#define K_ALL		99999



/*
 *	special keys.  These function keys skip normal edit checks
 */

#define	V_HELPKEY	2001		/* help */
#define	V_CANCEL	2002		/* cancel */
#define	V_REFRESH	2003		/* refresh screen */
#define V_XADD		2004
#if XWIN
#define V_XDLGBX	2005
#endif

/*
 *	miscellaneous keys.  These function keys are known
 *	to view support functions (vparam, vfcollect).
 */

#define	V_EXIT		3001		/* exit process */
#define	V_STORE		3002		/* store/process data */

/*
 *	view field_types in v_fld structure
 */

#define	VF_ENTRY	001	/* normal data entry field */
#define	VF_DISPLAY	002	/* display only of data in record */
#define	VF_TEXT		004	/* write text on screen; for field titles */
#define	VF_INVISIBLE	010	/* field not shown on screen */
#define	VF_REQUIRED	020	/* data entry required before storing record */
#define	VF_KEY		040	/* don't change field during update */



/*
 *	structure used for each screen field
 */

struct	v_fld {
	int	row;			/* row position on terminal screen */
	int	col;			/* column position on terminal screen */
	int	field_type;		/* screen field type (see above) */
	int	field_length;		/* length of field on screen */
	char	*text;			/* text if TEXT field */
	char	*fldname;		/* name of field */
	int	data_type;		/* data type from data dictionary */
	int	data_size;		/* size of data in data file */
	int	data_offset;		/* offset from beginning of record */
	int	has_data;		/* data was entered into field */
	int	prev_data;		/* valid data in prevbuf */
};

/*
 *	view form attributes
 */

#define	VS_APPEND	001	/* do not clear screen; append new form */
#define	VS_REPEAT	002	/* this form repeats */
#define	VS_FREEZE	004	/* freeze form on screen */



struct	w_set	{
	char	*fn_label;
	char 	*fn_string;
	char	*fg_string;
	char	*bg_string;
	char	*bi_string;
	char	*ba_string;
	char	*hf_string;
	char	*hb_string;
	char	*bx_string;
	int	size_x;
	int	size_y;
	int	options; 
};
/*
 *	structure used for each data entry form
 */
struct	v_form	{
	char	*formname;		/* name of this form */
	int	form_type;		/* view form attributes */
	int	form_length;		/* length of form in lines */
	struct	v_fld	*ffield;	/* first field of form */
	struct	v_fld	*lfield;	/* last field of form */
	char	*databuf;
	char	*origbuf;		/* record before update done */
	char	*prevbuf;		/* last modified record */
	int	rec_length;
	char	*fn_label;
	char 	*fn_string;
	char	*fg_string;
	char	*bg_string;
	char	*bi_string;
	char	*ba_string;
	char	*hf_string;
	char	*hb_string;
	char	*bx_string;
	int	size_x;
	int	size_y;
	int	options; 
};

/*
 *	structure used to define a view dialog area
 *
 *	This structure is typically built by vgetdlg()
 *	and is used by vopendlg().
 */

struct	v_dlg	{
	int	start_row;		/* starting row */
	int	start_col;		/* starting column (Unused) */
	int	end_row;		/* ending row */
	int	end_col;		/* ending column (Unused) */
};


struct	v_fld	*vhome();
struct	v_fld	*vprevfld();
struct	v_fld	*vnextfld();
char	*vread();
int	vcollect();
struct	v_fld	*vsetfld();
struct	v_fld	*vrequired();
struct	v_fld	*vcurfld();

struct	v_form	*vgetflds();
struct	v_dlg	*vgetdlg();
